ninjadog: pug + jinj2 == ❤️
===========================

.. image:: yodawg.jpg

.. include:: ../README.rst

Command Line Interface
----------------------

.. include:: ../ninjadog/cli.py
    :start-after: """
    :end-before: """
    :literal:

API Documentation
-----------------

.. include:: modules.rst
    :start-line: 2

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
